logrus

package module
v1.10.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2026 License: MIT Imports: 18 Imported by: 239,958

README

Logrus Build Status Go Reference

Logrus is a structured logger for Go (golang), completely API compatible with the standard library logger.

Logrus is in maintenance mode. The project focuses on security, bug fixes, and performance improvements. New features are not planned, aside from changes required to provide interoperability with other logging ecosystems (e.g., Go's log/slog).

I believe Logrus' biggest contribution is to have played a part in today's widespread use of structured logging in Golang. There doesn't seem to be a reason to do a major, breaking iteration into Logrus V2, since the fantastic Go community has built those independently. Many fantastic alternatives have sprung up. Logrus would look like those, had it been re-designed with what we know about structured logging in Go today. Check out, for example, Zerolog, Zap, and Apex.

Nicely color-coded in development (when a TTY is attached, otherwise just plain text):

Colored

With logrus.SetFormatter(&logrus.JSONFormatter{}), for easy parsing by logstash or Splunk:

{"animal":"walrus","level":"info","msg":"A group of walrus emerges from the ocean","size":10,"time":"2014-03-10 19:57:38.562264131 -0400 EDT"}
{"level":"warning","msg":"The group's number increased tremendously!","number":122,"omg":true,"time":"2014-03-10 19:57:38.562471297 -0400 EDT"}
{"animal":"walrus","level":"info","msg":"A giant walrus appears!","size":10,"time":"2014-03-10 19:57:38.562500591 -0400 EDT"}
{"animal":"walrus","level":"info","msg":"Tremendously sized cow enters the ocean.","size":9,"time":"2014-03-10 19:57:38.562527896 -0400 EDT"}
{"level":"fatal","msg":"The ice breaks!","number":100,"omg":true,"time":"2014-03-10 19:57:38.562543128 -0400 EDT"}

With the default logrus.SetFormatter(&logrus.TextFormatter{}) when a TTY is not attached, the output is compatible with the logfmt format:

time="2015-03-26T01:27:38-04:00" level=debug msg="Started observing beach" animal=walrus number=8
time="2015-03-26T01:27:38-04:00" level=info msg="A group of walrus emerges from the ocean" animal=walrus size=10
time="2015-03-26T01:27:38-04:00" level=warning msg="The group's number increased tremendously!" number=122 omg=true
time="2015-03-26T01:27:38-04:00" level=debug msg="Temperature changes" temperature=-4
time="2015-03-26T01:27:38-04:00" level=panic msg="It's over 9000!" animal=orca size=9009
time="2015-03-26T01:27:38-04:00" level=fatal msg="The ice breaks!" animal=orca err="It's over 9000!" number=100 omg=true size=9009

To ensure this behaviour even if a TTY is attached, set your formatter as follows:

logrus.SetFormatter(&logrus.TextFormatter{
    DisableColors: true,
    FullTimestamp: true,
})
Logging Method Name

If you wish to add the calling method as a field, instruct the logger via:

logrus.SetReportCaller(true)

This adds the caller as 'method' like so:

{"animal":"penguin","level":"fatal","method":"github.com/sirupsen/arcticcreatures.migrate","msg":"a penguin swims by","time":"2014-03-10 19:57:38.562543129 -0400 EDT"}
time="2015-03-26T01:27:38-04:00" level=fatal method=github.com/sirupsen/arcticcreatures.migrate msg="a penguin swims by" animal=penguin

Note that this does add measurable overhead - the cost will depend on the version of Go, but is between 20 and 40% in recent tests with 1.6 and 1.7. You can validate this in your environment via benchmarks:

go test -bench=ReportCaller
Case-sensitivity

The organization's name was changed to lower-case. If you are getting import conflicts due to case sensitivity, please use the lower-case import: github.com/sirupsen/logrus.

Example

The simplest way to use Logrus is simply the package-level exported logger:

package main

import "github.com/sirupsen/logrus"

func main() {
  logrus.WithFields(logrus.Fields{
    "animal": "walrus",
  }).Info("A walrus appears")
}

Note that it's completely api-compatible with the stdlib logger, so you can replace your log imports everywhere with log "github.com/sirupsen/logrus" and you'll now have the flexibility of Logrus. You can customize it all you want:

package main

import (
  "os"

  log "github.com/sirupsen/logrus"
)

func init() {
  // Log as JSON instead of the default ASCII formatter.
  log.SetFormatter(&log.JSONFormatter{})

  // Output to stdout instead of the default stderr
  // Can be any io.Writer, see below for File example
  log.SetOutput(os.Stdout)

  // Only log the warning severity or above.
  log.SetLevel(log.WarnLevel)
}

func main() {
  log.WithFields(log.Fields{
    "animal": "walrus",
    "size":   10,
  }).Info("A group of walrus emerges from the ocean")

  log.WithFields(log.Fields{
    "omg":    true,
    "number": 122,
  }).Warn("The group's number increased tremendously!")

  log.WithFields(log.Fields{
    "omg":    true,
    "number": 100,
  }).Fatal("The ice breaks!")

  // A common pattern is to re-use fields between logging statements by re-using
  // the logrus.Entry returned from WithFields()
  contextLogger := log.WithFields(log.Fields{
    "common": "this is a common field",
    "other": "I also should be logged always",
  })

  contextLogger.Info("I'll be logged with common and other field")
  contextLogger.Info("Me too")
}

For more advanced usage such as logging to multiple locations from the same application, you can also create an instance of the logrus Logger:

package main

import (
  "os"

  "github.com/sirupsen/logrus"
)

// Create a new instance of the logger. You can have any number of instances.
var logger = logrus.New()

func main() {
  // The API for setting attributes is a little different than the package level
  // exported logger. See Godoc. 
  logger.Out = os.Stdout

  // You could set this to any `io.Writer` such as a file
  // file, err := os.OpenFile("logrus.log", os.O_CREATE|os.O_WRONLY|os.O_APPEND, 0666)
  // if err == nil {
  //  logger.Out = file
  // } else {
  //  logger.Info("Failed to log to file, using default stderr")
  // }

  logger.WithFields(logrus.Fields{
    "animal": "walrus",
    "size":   10,
  }).Info("A group of walrus emerges from the ocean")
}
Fields

Logrus encourages careful, structured logging through logging fields instead of long, unparseable error messages. For example, instead of: logrus.Fatalf("Failed to send event %s to topic %s with key %d"), you should log the much more discoverable:

logrus.WithFields(logrus.Fields{
  "event": event,
  "topic": topic,
  "key": key,
}).Fatal("Failed to send event")

We've found this API forces you to think about logging in a way that produces much more useful logging messages. We've been in countless situations where just a single added field to a log statement that was already there would've saved us hours. The WithFields call is optional.

In general, with Logrus using any of the printf-family functions should be seen as a hint you should add a field, however, you can still use the printf-family functions with Logrus.

Default Fields

Often it's helpful to have fields always attached to log statements in an application or parts of one. For example, you may want to always log the request_id and user_ip in the context of a request. Instead of writing logger.WithFields(logrus.Fields{"request_id": request_id, "user_ip": user_ip}) on every line, you can create a logrus.Entry to pass around instead:

requestLogger := logger.WithFields(logrus.Fields{"request_id": request_id, "user_ip": user_ip})
requestLogger.Info("something happened on that request") // will log request_id and user_ip
requestLogger.Warn("something not great happened")
Hooks

You can add hooks for logging levels. For example to send errors to an exception tracking service on Error, Fatal and Panic, info to StatsD or log to multiple places simultaneously, e.g. syslog.

Logrus comes with built-in hooks. Add those, or your custom hook, in init:

package main

import (
  "log/syslog"

  "github.com/sirupsen/logrus"
  airbrake "gopkg.in/gemnasium/logrus-airbrake-hook.v2"
  logrus_syslog "github.com/sirupsen/logrus/hooks/syslog"
)

func init() {

  // Use the Airbrake hook to report errors that have Error severity or above to
  // an exception tracker. You can create custom hooks, see the Hooks section.
  logrus.AddHook(airbrake.NewHook(123, "xyz", "production"))

  hook, err := logrus_syslog.NewSyslogHook("udp", "localhost:514", syslog.LOG_INFO, "")
  if err != nil {
    logrus.Error("Unable to connect to local syslog daemon")
  } else {
    logrus.AddHook(hook)
  }
}

Note: Syslog hooks also support connecting to local syslog (Ex. "/dev/log" or "/var/run/syslog" or "/var/run/log"). For the detail, please check the syslog hook README.

A list of currently known service hooks can be found in this wiki page

Level logging

Logrus has seven logging levels: Trace, Debug, Info, Warning, Error, Fatal and Panic.

logrus.Trace("Something very low level.")
logrus.Debug("Useful debugging information.")
logrus.Info("Something noteworthy happened!")
logrus.Warn("You should probably take a look at this.")
logrus.Error("Something failed but I'm not quitting.")
// Calls os.Exit(1) after logging
logrus.Fatal("Bye.")
// Calls panic() after logging
logrus.Panic("I'm bailing.")

You can set the logging level on a Logger, then it will only log entries with that severity or anything above it:

// Will log anything that is info or above (warn, error, fatal, panic). Default.
logrus.SetLevel(logrus.InfoLevel)

It may be useful to set logrus.Level = logrus.DebugLevel in a debug or verbose environment if your application has that.

Note: If you want different log levels for global (logrus.SetLevel(...)) and syslog logging, please check the syslog hook README.

Entries

Besides the fields added with WithField or WithFields some fields are automatically added to all logging events:

  1. time. The timestamp when the entry was created.
  2. msg. The logging message passed to {Info,Warn,Error,Fatal,Panic} after the AddFields call. E.g. Failed to send event.
  3. level. The logging level. E.g. info.
Environments

Logrus has no notion of environment.

If you wish for hooks and formatters to only be used in specific environments, you should handle that yourself. For example, if your application has a global variable Environment, which is a string representation of the environment you could do:

import (
  "github.com/sirupsen/logrus"
)

func init() {
  // do something here to set environment depending on an environment variable
  // or command-line flag
  if Environment == "production" {
    logrus.SetFormatter(&logrus.JSONFormatter{})
  } else {
    // The TextFormatter is default, you don't actually have to do this.
    logrus.SetFormatter(&logrus.TextFormatter{})
  }
}

This configuration is how logrus was intended to be used, but JSON in production is mostly only useful if you do log aggregation with tools like Splunk or Logstash.

Formatters

The built-in logging formatters are:

  • logrus.TextFormatter logs the event in colors if the logger output is a TTY, otherwise without colors.
    • To force colored output when there is no TTY, set the ForceColors field to true. To force no colored output even if there is a TTY set the DisableColors field to true.
    • On modern Windows terminals with ANSI (Virtual Terminal) support, TextFormatter automatically enables colored output.
    • If your environment does not support ANSI escape sequences, wrap the logger output using github.com/mattn/go-colorable and set ForceColors (or CLICOLOR_FORCE=1) to enable colors through the wrapper.
    • When colors are enabled, levels are truncated to 4 characters by default. To disable truncation set the DisableLevelTruncation field to true.
    • When outputting to a TTY, it's often helpful to visually scan down a column where all the levels are the same width. Setting the PadLevelText field to true enables this behavior, by adding padding to the level text.
  • logrus.JSONFormatter logs fields as JSON.

Third-party logging formatters:

You can define your formatter by implementing the Formatter interface, requiring a Format method. Format takes an *Entry. entry.Data is a Fields type (map[string]any) with all your fields as well as the default ones (see Entries section above):

type MyJSONFormatter struct{}

logrus.SetFormatter(new(MyJSONFormatter))

func (f *MyJSONFormatter) Format(entry *Entry) ([]byte, error) {
  // Note this doesn't include Time, Level and Message which are available on
  // the Entry. Consult `godoc` on information about those fields or read the
  // source of the official loggers.
  serialized, err := json.Marshal(entry.Data)
    if err != nil {
      return nil, fmt.Errorf("Failed to marshal fields to JSON, %w", err)
    }
  return append(serialized, '\n'), nil
}
Logger as an io.Writer

Logrus can be transformed into an io.Writer. That writer is the end of an io.Pipe and it is your responsibility to close it.

w := logger.Writer()
defer w.Close()

srv := http.Server{
    // create a stdlib log.Logger that writes to
    // logrus.Logger.
    ErrorLog: log.New(w, "", 0),
}

Each line written to that writer will be printed the usual way, using formatters and hooks. The level for those entries is info.

This means that we can override the standard library logger easily:

logger := logrus.New()
logger.Formatter = &logrus.JSONFormatter{}

// Use logrus for standard log output
// Note that `log` here references stdlib's log
// Not logrus imported under the name `log`.
log.SetOutput(logger.Writer())
Rotation

Log rotation is not provided with Logrus. Log rotation should be done by an external program (like logrotate(8)) that can compress and delete old log entries. It should not be a feature of the application-level logger.

Tools
Tool Description
Logrus Mate Logrus mate is a tool for Logrus to manage loggers, you can initial logger's level, hook and formatter by config file, the logger will be generated with different configs in different environments.
Logrus Viper Helper An Helper around Logrus to wrap with spf13/Viper to load configuration with fangs! And to simplify Logrus configuration use some behavior of Logrus Mate. sample
Testing

Logrus has a built-in facility for asserting the presence of log messages. This is implemented through the test hook and provides:

  • decorators for existing logger (test.NewLocal and test.NewGlobal) which basically just adds the test hook
  • a test logger (test.NewNullLogger) that just records log messages (and does not output any):
import(
  "testing"

  "github.com/sirupsen/logrus"
  "github.com/sirupsen/logrus/hooks/test"
  "github.com/stretchr/testify/assert"
)

func TestSomething(t*testing.T){
  logger, hook := test.NewNullLogger()
  logger.Error("Helloerror")

  assert.Equal(t, 1, len(hook.Entries))
  assert.Equal(t, logrus.ErrorLevel, hook.LastEntry().Level)
  assert.Equal(t, "Helloerror", hook.LastEntry().Message)

  hook.Reset()
  assert.Nil(t, hook.LastEntry())
}
Fatal handlers

Logrus can register one or more functions that will be called when any fatal level message is logged. The registered handlers will be executed before logrus performs an os.Exit(1). This behavior may be helpful if callers need to gracefully shut down. Unlike a panic("Something went wrong...") call which can be intercepted with a deferred recover a call to os.Exit(1) can not be intercepted.

// ...
handler := func() {
  // gracefully shut down something...
}
logrus.RegisterExitHandler(handler)
// ...
Thread safety

By default, Logger is protected by a mutex for concurrent writes. The mutex is held when calling hooks and writing logs. If you are sure such locking is not needed, you can call logger.SetNoLock() to disable the locking.

Situations when locking is not needed include:

  • You have no hooks registered, or hooks calling is already thread-safe.

  • Writing to logger.Out is already thread-safe, for example:

    1. logger.Out is protected by locks.

    2. logger.Out is an os.File handler opened with O_APPEND flag, and every write is smaller than 4k. (This allows multi-thread/multi-process writing)

      (Refer to http://www.notthewizard.com/2014/06/17/are-files-appends-really-atomic/)

Documentation

Overview

Package logrus is a structured logger for Go, completely API compatible with the standard library logger.

The simplest way to use Logrus is simply the package-level exported logger:

package main

import (
	log "github.com/sirupsen/logrus"
)

func main() {
	log.WithFields(log.Fields{
		"animal": "walrus",
		"number": 1,
		"size":   10,
	}).Info("A walrus appears")
}

Output:

time="2015-09-07T08:48:33Z" level=info msg="A walrus appears" animal=walrus number=1 size=10

For a full guide visit https://github.com/sirupsen/logrus

Example (Basic)
package main

import (
	"os"

	"github.com/sirupsen/logrus"
)

func main() {
	log := logrus.New()
	log.Formatter = new(logrus.JSONFormatter)
	log.Formatter = new(logrus.TextFormatter)                     // default
	log.Formatter.(*logrus.TextFormatter).DisableColors = true    // remove colors
	log.Formatter.(*logrus.TextFormatter).DisableTimestamp = true // remove timestamp from test output
	log.Level = logrus.TraceLevel
	log.Out = os.Stdout

	// file, err := os.OpenFile("logrus.log", os.O_CREATE|os.O_WRONLY, 0666)
	// if err == nil {
	// 	log.Out = file
	// } else {
	// 	log.Info("Failed to log to file, using default stderr")
	// }

	defer func() {
		err := recover()
		if err != nil {
			entry := err.(*logrus.Entry)
			log.WithFields(logrus.Fields{
				"omg":         true,
				"err_animal":  entry.Data["animal"],
				"err_size":    entry.Data["size"],
				"err_level":   entry.Level,
				"err_message": entry.Message,
				"number":      100,
			}).Error("The ice breaks!") // or use Fatal() to force the process to exit with a nonzero code
		}
	}()

	log.WithFields(logrus.Fields{
		"animal": "walrus",
		"number": 0,
	}).Trace("Went to the beach")

	log.WithFields(logrus.Fields{
		"animal": "walrus",
		"number": 8,
	}).Debug("Started observing beach")

	log.WithFields(logrus.Fields{
		"animal": "walrus",
		"size":   10,
	}).Info("A group of walrus emerges from the ocean")

	log.WithFields(logrus.Fields{
		"omg":    true,
		"number": 122,
	}).Warn("The group's number increased tremendously!")

	log.WithFields(logrus.Fields{
		"temperature": -4,
	}).Debug("Temperature changes")

	log.WithFields(logrus.Fields{
		"animal": "orca",
		"size":   9009,
	}).Panic("It's over 9000!")

}
Output:
level=trace msg="Went to the beach" animal=walrus number=0
level=debug msg="Started observing beach" animal=walrus number=8
level=info msg="A group of walrus emerges from the ocean" animal=walrus size=10
level=warning msg="The group's number increased tremendously!" number=122 omg=true
level=debug msg="Temperature changes" temperature=-4
level=panic msg="It's over 9000!" animal=orca size=9009
level=error msg="The ice breaks!" err_animal=orca err_level=panic err_message="It's over 9000!" err_size=9009 number=100 omg=true
Example (Hook)

An example on how to use a hook

package main

import (
	"log/syslog"
	"os"

	"github.com/sirupsen/logrus"
	slhooks "github.com/sirupsen/logrus/hooks/syslog"
)

func main() {
	log := logrus.New()
	log.Formatter = new(logrus.TextFormatter)                     // default
	log.Formatter.(*logrus.TextFormatter).DisableColors = true    // remove colors
	log.Formatter.(*logrus.TextFormatter).DisableTimestamp = true // remove timestamp from test output
	if sl, err := slhooks.NewSyslogHook("udp", "localhost:514", syslog.LOG_INFO, ""); err == nil {
		log.Hooks.Add(sl)
	}
	log.Out = os.Stdout

	log.WithFields(logrus.Fields{
		"animal": "walrus",
		"size":   10,
	}).Info("A group of walrus emerges from the ocean")

	log.WithFields(logrus.Fields{
		"omg":    true,
		"number": 122,
	}).Warn("The group's number increased tremendously!")

	log.WithFields(logrus.Fields{
		"omg":    true,
		"number": 100,
	}).Error("The ice breaks!")

}
Output:
level=info msg="A group of walrus emerges from the ocean" animal=walrus size=10
level=warning msg="The group's number increased tremendously!" number=122 omg=true
level=error msg="The ice breaks!" number=100 omg=true

Index

Examples

Constants

const (
	FieldKeyMsg         = "msg"
	FieldKeyLevel       = "level"
	FieldKeyTime        = "time"
	FieldKeyLogrusError = "logrus_error"
	FieldKeyFunc        = "func"
	FieldKeyFile        = "file"
)

Default key names for the default fields

Variables

AllLevels exposing all logging levels.

var ErrorKey = "error"

ErrorKey defines the key when adding errors using WithError, Logger.WithError.

Functions

func AddHook added in v0.4.0

func AddHook(hook Hook)

AddHook adds a hook to the standard logger hooks.

func Debug

func Debug(args ...any)

Debug logs a message at level DebugLevel on the standard logger.

func DebugFn added in v1.7.0

func DebugFn(fn LogFunction)

DebugFn logs a message from a func at level DebugLevel on the standard logger.

func Debugf added in v0.4.1

func Debugf(format string, args ...any)

Debugf logs a message at level DebugLevel on the standard logger.

func Debugln added in v0.4.1

func Debugln(args ...any)

Debugln logs a message at level DebugLevel on the standard logger.

func DeferExitHandler added in v1.4.0

func DeferExitHandler(handler func())

DeferExitHandler prepends a Logrus Exit handler to the list of handlers, call logrus.Exit to invoke all handlers. The handlers will also be invoked when any Fatal log entry is made.

This method is useful when a caller wishes to use logrus to log a fatal message but also needs to gracefully shutdown. An example usecase could be closing database connections, or sending an alert that the application is closing.

func Error

func Error(args ...any)

Error logs a message at level ErrorLevel on the standard logger.

func ErrorFn added in v1.7.0

func ErrorFn(fn LogFunction)

ErrorFn logs a message from a func at level ErrorLevel on the standard logger.

func Errorf added in v0.4.1

func Errorf(format string, args ...any)

Errorf logs a message at level ErrorLevel on the standard logger.

func Errorln added in v0.4.1

func Errorln(args ...any)

Errorln logs a message at level ErrorLevel on the standard logger.

func Exit added in v0.11.0

func Exit(code int)

Exit runs all the Logrus atexit handlers and then terminates the program using os.Exit(code)

func Fatal

func Fatal(args ...any)

Fatal logs a message at level FatalLevel on the standard logger, then exits the process with status 1.

func FatalFn added in v1.7.0

func FatalFn(fn LogFunction)

FatalFn logs a message from a func at level FatalLevel on the standard logger, then exits the process with status 1.

func Fatalf added in v0.4.1

func Fatalf(format string, args ...any)

Fatalf logs a message at level FatalLevel on the standard logger, then exits the process with status 1.

func Fatalln added in v0.4.1

func Fatalln(args ...any)

Fatalln logs a message at level FatalLevel on the standard logger, then exits the process with status 1.

func Info

func Info(args ...any)

Info logs a message at level InfoLevel on the standard logger.

func InfoFn added in v1.7.0

func InfoFn(fn LogFunction)

InfoFn logs a message from a func at level InfoLevel on the standard logger.

func Infof added in v0.4.1

func Infof(format string, args ...any)

Infof logs a message at level InfoLevel on the standard logger.

func Infoln added in v0.4.1

func Infoln(args ...any)

Infoln logs a message at level InfoLevel on the standard logger.

func IsLevelEnabled added in v1.1.0

func IsLevelEnabled(level Level) bool

IsLevelEnabled checks if logging for the given level is enabled for the standard logger.

func Panic

func Panic(args ...any)

Panic logs a message at level PanicLevel on the standard logger.

func PanicFn added in v1.7.0

func PanicFn(fn LogFunction)

PanicFn logs a message from a func at level PanicLevel on the standard logger.

func Panicf added in v0.4.1

func Panicf(format string, args ...any)

Panicf logs a message at level PanicLevel on the standard logger.

func Panicln added in v0.4.1

func Panicln(args ...any)

Panicln logs a message at level PanicLevel on the standard logger.

func Print added in v0.4.1

func Print(args ...any)

Print logs a message at level InfoLevel on the standard logger.

func PrintFn added in v1.7.0

func PrintFn(fn LogFunction)

PrintFn logs a message from a func at level InfoLevel on the standard logger.

func Printf added in v0.4.1

func Printf(format string, args ...any)

Printf logs a message at level InfoLevel on the standard logger.

func Println added in v0.4.1

func Println(args ...any)

Println logs a message at level InfoLevel on the standard logger.

func RegisterExitHandler added in v0.11.0

func RegisterExitHandler(handler func())

RegisterExitHandler appends a Logrus Exit handler to the list of handlers, call logrus.Exit to invoke all handlers. The handlers will also be invoked when any Fatal log entry is made.

This method is useful when a caller wishes to use logrus to log a fatal message but also needs to gracefully shutdown. An example usecase could be closing database connections, or sending an alert that the application is closing.

func SetBufferPool added in v1.7.0

func SetBufferPool(bp BufferPool)

SetBufferPool allows to replace the default logrus buffer pool to better meet the specific needs of an application.

func SetFormatter added in v0.4.0

func SetFormatter(formatter Formatter)

SetFormatter sets the standard logger formatter.

func SetLevel added in v0.4.0

func SetLevel(level Level)

SetLevel sets the standard logger level.

func SetOutput added in v0.4.0

func SetOutput(out io.Writer)

SetOutput sets the standard logger output.

func SetReportCaller added in v1.2.0

func SetReportCaller(include bool)

SetReportCaller sets whether the standard logger will include the calling method as a field.

func Trace added in v1.2.0

func Trace(args ...any)

Trace logs a message at level TraceLevel on the standard logger.

func TraceFn added in v1.7.0

func TraceFn(fn LogFunction)

TraceFn logs a message from a func at level TraceLevel on the standard logger.

func Tracef added in v1.2.0

func Tracef(format string, args ...any)

Tracef logs a message at level TraceLevel on the standard logger.

func Traceln added in v1.2.0

func Traceln(args ...any)

Traceln logs a message at level TraceLevel on the standard logger.

func Warn

func Warn(args ...any)

Warn logs a message at level WarnLevel on the standard logger.

func WarnFn added in v1.7.0

func WarnFn(fn LogFunction)

WarnFn logs a message from a func at level WarnLevel on the standard logger.

func Warnf added in v0.4.1

func Warnf(format string, args ...any)

Warnf logs a message at level WarnLevel on the standard logger.

func Warning added in v0.4.1

func Warning(args ...any)

Warning logs a message at level WarnLevel on the standard logger.

func WarningFn added in v1.7.0

func WarningFn(fn LogFunction)

WarningFn logs a message from a func at level WarnLevel on the standard logger.

func Warningf added in v0.4.1

func Warningf(format string, args ...any)

Warningf logs a message at level WarnLevel on the standard logger.

func Warningln added in v0.4.1

func Warningln(args ...any)

Warningln logs a message at level WarnLevel on the standard logger.

func Warnln added in v0.4.1

func Warnln(args ...any)

Warnln logs a message at level WarnLevel on the standard logger.

Types

type BufferPool added in v1.7.0

type BufferPool interface {
	Put(*bytes.Buffer)
	Get() *bytes.Buffer
}

type DebugLogger added in v1.10.0

type DebugLogger interface {
	Debug(args ...any)
	Debugf(format string, args ...any)
	Debugln(args ...any)
}

DebugLogger provides convenience functions to log messages at level DebugLevel.

type Entry

type Entry struct {
	// Logger is the Logger that owns this entry and is responsible for
	// formatting, hooks, and output. It must not be nil. An Entry without
	// a Logger is invalid and will panic when logged.
	Logger *Logger

	// Data contains all user-defined fields attached to this entry.
	Data Fields

	// Time is the timestamp for the log event. If zero when the entry is
	// logged, it defaults to the current time.
	Time time.Time

	// Level is the severity of the log entry. It is set when the entry
	// is fired and reflects the level used for that log call.
	Level Level

	// Caller contains the calling method information.
	//
	// When [Logger.ReportCaller] is enabled, Caller is populated automatically at
	// log time if it is nil. Hooks and formatters may inspect Caller.
	//
	// Applications generally should not modify Caller unless they intentionally
	// want to provide custom caller information.
	Caller *runtime.Frame

	// Message is the log message supplied to one of the logging methods
	// (Trace, Debug, Info, Warn, Error, Fatal, or Panic). It is set when
	// the entry is logged.
	Message string

	// Buffer is a reusable buffer provided to the formatter. It is set
	// before formatting in the normal log path; when nil, formatters
	// allocate their own.
	Buffer *bytes.Buffer

	// Context carries user-provided context for hooks and formatters.
	Context context.Context
	// contains filtered or unexported fields
}

Entry represents a single log event. It may be either an intermediate entry (created via WithField(s), WithContext, etc.) or a final entry that is emitted when one of the level methods (Trace, Debug, Info, Warn, Error, Fatal, Panic) is called.

An Entry always belongs to a Logger. A nil Logger is invalid and will cause a panic when the entry is logged. Use NewEntry or Logger methods to construct entries.

Entries are safe to reuse for adding fields and may be passed around to avoid field duplication. Each log operation operates on a copy of the Entry’s data to avoid mutation during formatting.

func NewEntry

func NewEntry(logger *Logger) *Entry

NewEntry creates a new Entry associated with the provided Logger. The logger must not be nil. Passing a nil logger results in a panic when a logging method (e.g., Entry.Info, Entry.Error, etc.) is called.

func WithContext added in v1.4.0

func WithContext(ctx context.Context) *Entry

WithContext creates an entry from the standard logger and adds a context to it.

func WithError added in v0.8.7

func WithError(err error) *Entry

WithError creates an entry from the standard logger and adds an error to it, using the value defined in ErrorKey as key.

func WithField added in v0.4.0

func WithField(key string, value any) *Entry

WithField creates an entry from the standard logger and adds a single field. For multiple fields, prefer WithFields over chaining WithField calls.

func WithFields added in v0.4.0

func WithFields(fields Fields) *Entry

WithFields creates an entry from the standard logger and adds the fields to it.

func WithTime added in v1.0.6

func WithTime(t time.Time) *Entry

WithTime creates an entry from the standard logger and overrides the time used for logs generated with it.

func (*Entry) Bytes added in v1.5.0

func (entry *Entry) Bytes() ([]byte, error)

Bytes returns the bytes representation of this entry from the formatter.

func (*Entry) Debug

func (entry *Entry) Debug(args ...any)

func (*Entry) Debugf

func (entry *Entry) Debugf(format string, args ...any)

func (*Entry) Debugln

func (entry *Entry) Debugln(args ...any)

func (*Entry) Dup added in v1.7.1

func (entry *Entry) Dup() *Entry

Dup creates a copy of the entry for further modification.

Data is cloned to avoid mutating the original entry. Other fields (Logger, Time, Context, etc.) are copied by value.

func (*Entry) Error

func (entry *Entry) Error(args ...any)

func (*Entry) Errorf

func (entry *Entry) Errorf(format string, args ...any)

func (*Entry) Errorln

func (entry *Entry) Errorln(args ...any)

func (*Entry) Fatal

func (entry *Entry) Fatal(args ...any)

func (*Entry) Fatalf

func (entry *Entry) Fatalf(format string, args ...any)

func (*Entry) Fatalln

func (entry *Entry) Fatalln(args ...any)

func (Entry) HasCaller deprecated added in v1.2.0

func (entry Entry) HasCaller() bool

HasCaller reports whether this Entry contains caller information.

Caller may be set explicitly, or populated at log time when Logger.ReportCaller is enabled.

Deprecated: use Entry.Caller != nil instead.

func (*Entry) Info

func (entry *Entry) Info(args ...any)

func (*Entry) Infof

func (entry *Entry) Infof(format string, args ...any)

func (*Entry) Infoln

func (entry *Entry) Infoln(args ...any)

func (*Entry) Log added in v1.3.0

func (entry *Entry) Log(level Level, args ...any)

Log logs a message at the specified level.

Using Log with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. Log treats the level as logging severity only; use Entry.Panic or Entry.Fatal when those side effects are desired.

func (*Entry) Logf added in v1.3.0

func (entry *Entry) Logf(level Level, format string, args ...any)

Logf logs a formatted message at the specified level.

Using Logf with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. Logf treats the level as logging severity only; use Entry.Panicf or Entry.Fatalf when those side effects are desired.

func (*Entry) Logln added in v1.3.0

func (entry *Entry) Logln(level Level, args ...any)

Logln logs a message at the specified level with Println-style spacing.

Using Logln with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. Logln treats the level as logging severity only; use Entry.Panicln or Entry.Fatalln when those side effects are desired.

func (*Entry) Panic

func (entry *Entry) Panic(args ...any)

func (*Entry) Panicf

func (entry *Entry) Panicf(format string, args ...any)

func (*Entry) Panicln

func (entry *Entry) Panicln(args ...any)

func (*Entry) Print

func (entry *Entry) Print(args ...any)

func (*Entry) Printf

func (entry *Entry) Printf(format string, args ...any)

func (*Entry) Println

func (entry *Entry) Println(args ...any)

func (*Entry) String

func (entry *Entry) String() (string, error)

String returns the string representation from the reader and ultimately the formatter.

func (*Entry) Trace added in v1.2.0

func (entry *Entry) Trace(args ...any)

func (*Entry) Tracef added in v1.2.0

func (entry *Entry) Tracef(format string, args ...any)

func (*Entry) Traceln added in v1.2.0

func (entry *Entry) Traceln(args ...any)

func (*Entry) Warn

func (entry *Entry) Warn(args ...any)

func (*Entry) Warnf

func (entry *Entry) Warnf(format string, args ...any)

func (*Entry) Warning added in v0.6.3

func (entry *Entry) Warning(args ...any)

func (*Entry) Warningf

func (entry *Entry) Warningf(format string, args ...any)

func (*Entry) Warningln

func (entry *Entry) Warningln(args ...any)

func (*Entry) Warnln

func (entry *Entry) Warnln(args ...any)

func (*Entry) WithContext added in v1.4.0

func (entry *Entry) WithContext(ctx context.Context) *Entry

WithContext adds a context to the Entry.

func (*Entry) WithError added in v0.8.7

func (entry *Entry) WithError(err error) *Entry

WithError adds an error as single field (using the key defined in ErrorKey) to the Entry.

func (*Entry) WithField

func (entry *Entry) WithField(key string, value any) *Entry

WithField adds a single field to the Entry.

func (*Entry) WithFields

func (entry *Entry) WithFields(fields Fields) *Entry

WithFields adds a map of fields to the Entry.

func (*Entry) WithTime added in v1.0.6

func (entry *Entry) WithTime(t time.Time) *Entry

WithTime overrides the time of the Entry.

func (*Entry) Writer added in v0.11.5

func (entry *Entry) Writer() *io.PipeWriter

Writer returns an io.Writer that writes to the logger at the info log level

func (*Entry) WriterLevel added in v0.11.5

func (entry *Entry) WriterLevel(level Level) *io.PipeWriter

WriterLevel returns an io.Writer that writes to the logger at the given log level

type ErrorLogger added in v1.10.0

type ErrorLogger interface {
	Error(args ...any)
	Errorf(format string, args ...any)
	Errorln(args ...any)
}

ErrorLogger provides convenience functions to log messages at level ErrorLevel.

type Ext1FieldLogger added in v1.2.0

type Ext1FieldLogger interface {
	FieldLogger
	TraceLogger
}

Ext1FieldLogger is FieldLogger extended with Trace-level methods.

New code should prefer the smallest applicable interface, such as FieldLogger or TraceLogger, or use Logger or Entry directly.

type FieldLogger added in v0.10.0

type FieldLogger interface {
	WithField(key string, value any) *Entry
	WithFields(fields Fields) *Entry
	WithError(err error) *Entry

	StdLogger
	DebugLogger
	InfoLogger
	WarnLogger
	ErrorLogger

	Warning(args ...any)
	Warningf(format string, args ...any)
	Warningln(args ...any)
}

FieldLogger extends the StdLogger interface, generalizing the Entry and Logger types.

type FieldMap added in v0.11.1

type FieldMap map[fieldKey]string

FieldMap allows customization of the key names for default fields.

type Fields

type Fields map[string]any

Fields type, used to pass to WithFields.

type Formatter

type Formatter interface {
	Format(*Entry) ([]byte, error)
}

Formatter is implemented by types that format log entries. It receives an *Entry, which contains:

  • entry.Message: the message passed to logging methods such as Info, Warn, Error
  • entry.Time: the timestamp
  • entry.Level: the log level

Additional fields added with WithField or WithFields are available in Entry.Data. Format should return the formatted log entry as a byte slice, which is written to Logger.Out.

type Hook

type Hook interface {
	Levels() []Level
	Fire(*Entry) error
}

Hook describes hooks to be fired when logging on the logging levels returned from Hook.Levels on your implementation of the interface. Note that this is not fired in a goroutine or a channel with workers, you should handle such functionality yourself if your call is non-blocking, and you don't wish for the logging calls for levels returned from `Levels()` to block.

type InfoLogger added in v1.10.0

type InfoLogger interface {
	Info(args ...any)
	Infof(format string, args ...any)
	Infoln(args ...any)
}

InfoLogger provides convenience functions to log messages at level InfoLevel.

type JSONFormatter

type JSONFormatter struct {
	// TimestampFormat sets the format used for marshaling timestamps.
	// The format to use is the same than for time.Format or time.Parse from the standard
	// library.
	// The standard Library already provides a set of predefined format.
	TimestampFormat string

	// DisableTimestamp allows disabling automatic timestamps in output
	DisableTimestamp bool

	// DisableHTMLEscape allows disabling html escaping in output
	DisableHTMLEscape bool

	// DataKey allows users to put all the log entry parameters into a nested dictionary at a given key.
	DataKey string

	// FieldMap allows users to customize the names of keys for default fields.
	// As an example:
	// formatter := &JSONFormatter{
	//   	FieldMap: FieldMap{
	// 		 FieldKeyTime:  "@timestamp",
	// 		 FieldKeyLevel: "@level",
	// 		 FieldKeyMsg:   "@message",
	// 		 FieldKeyFunc:  "@caller",
	//    },
	// }
	FieldMap FieldMap

	// CallerPrettyfier can be set by the user to modify the content
	// of the function and file keys in the json data when ReportCaller is
	// activated. If any of the returned value is the empty string the
	// corresponding key will be removed from json fields.
	CallerPrettyfier func(*runtime.Frame) (function string, file string)

	// PrettyPrint will indent all json logs
	PrettyPrint bool
}

JSONFormatter formats logs into parsable JSON.

Fields from Entry.Data are included in the JSON object together with the standard fields derived from the entry. If a field conflicts with a standard field, it is prefixed with "fields.". Standard field names can be customized through FieldMap. When DataKey is set, fields from Entry.Data are nested under that key instead.

func (*JSONFormatter) Format

func (f *JSONFormatter) Format(entry *Entry) ([]byte, error)

Format renders a single log entry

type Level

type Level uint32

Level type

const (
	// PanicLevel level, highest level of severity. Logs and then calls panic with the
	// message passed to Debug, Info, ...
	PanicLevel Level = iota
	// FatalLevel level. Logs and then calls `logger.Exit(1)`. It will exit even if the
	// logging level is set to Panic.
	FatalLevel
	// ErrorLevel level. Logs. Used for errors that should definitely be noted.
	// Commonly used for hooks to send errors to an error tracking service.
	ErrorLevel
	// WarnLevel level. Non-critical entries that deserve eyes.
	WarnLevel
	// InfoLevel level. General operational entries about what's going on inside the
	// application.
	InfoLevel
	// DebugLevel level. Usually only enabled when debugging. Very verbose logging.
	DebugLevel
	// TraceLevel level. Designates finer-grained informational events than the Debug.
	TraceLevel
)

These are the different logging levels. You can set the logging level to log on your instance of logger, obtained with logrus.New.

func GetLevel added in v0.6.1

func GetLevel() Level

GetLevel returns the standard logger level.

func ParseLevel added in v0.6.0

func ParseLevel(lvl string) (Level, error)

ParseLevel takes a string level and returns the Logrus log level constant.

func (Level) MarshalText added in v1.3.0

func (level Level) MarshalText() ([]byte, error)

func (Level) String added in v0.4.0

func (level Level) String() string

Convert the Level to a string. E.g. PanicLevel becomes "panic".

func (*Level) UnmarshalText added in v1.2.0

func (level *Level) UnmarshalText(text []byte) error

UnmarshalText implements encoding.TextUnmarshaler.

type LevelHooks added in v0.8.3

type LevelHooks map[Level][]Hook

LevelHooks is an internal type for storing the hooks on a logger instance.

func (LevelHooks) Add added in v0.8.3

func (hooks LevelHooks) Add(hook Hook)

Add a hook to an instance of logger. This is called with `log.Hooks.Add(new(MyHook))` where `MyHook` implements the `Hook` interface.

func (LevelHooks) Fire added in v0.8.3

func (hooks LevelHooks) Fire(level Level, entry *Entry) error

Fire all the hooks for the passed level. Used by `entry.log` to fire appropriate hooks for a log entry.

type LogFunction added in v1.7.0

type LogFunction func() []any

LogFunction For big messages, it can be more efficient to pass a function and only call it if the log level is actually enables rather than generating the log message and then checking if the level is enabled

type Logger

type Logger struct {
	// The logs are `io.Copy`'d to this in a mutex. It's common to set this to a
	// file, or leave it default which is `os.Stderr`. You can also set this to
	// something more adventurous, such as logging to Kafka.
	Out io.Writer

	// Hooks for the logger instance. These allow firing events based on logging
	// levels and log entries. For example, to send errors to an error tracking
	// service, log to StatsD or dump the core on fatal errors.
	Hooks LevelHooks

	// All log entries pass through the formatter before logged to Out. The
	// included formatters are `TextFormatter` and `JSONFormatter` for which
	// TextFormatter is the default. In development (when a TTY is attached) it
	// logs with colors, but to a file it wouldn't. You can easily implement your
	// own that implements the `Formatter` interface, see the `README` or included
	// formatters for examples.
	Formatter Formatter

	// Flag for whether to log caller info (off by default)
	ReportCaller bool

	// The logging level the logger should log at. This is typically (and defaults
	// to) `logrus.Info`, which allows Info(), Warn(), Error() and Fatal() to be
	// logged.
	Level Level

	// Function to exit the application, defaults to `os.Exit()`
	ExitFunc func(int)

	// The buffer pool used to format the log. If it is nil, the default global
	// buffer pool will be used.
	BufferPool BufferPool
	// contains filtered or unexported fields
}

func New

func New() *Logger

New Creates a new logger. Configuration should be set by changing Formatter, Out and Hooks directly on the default Logger instance. You can also just instantiate your own:

var log = &logrus.Logger{
  Out:       os.Stderr,
  Formatter: new(logrus.TextFormatter),
  Hooks:     make(logrus.LevelHooks),
  Level:     logrus.DebugLevel,
}

It's recommended to make this a global instance called `log`.

func StandardLogger added in v0.6.5

func StandardLogger() *Logger

StandardLogger returns the package-level standard logger used by the top-level logging functions.

func (*Logger) AddHook added in v1.0.4

func (logger *Logger) AddHook(hook Hook)

AddHook adds a hook to the logger hooks.

func (*Logger) Debug

func (logger *Logger) Debug(args ...any)

func (*Logger) DebugFn added in v1.7.0

func (logger *Logger) DebugFn(fn LogFunction)

func (*Logger) Debugf

func (logger *Logger) Debugf(format string, args ...any)

func (*Logger) Debugln

func (logger *Logger) Debugln(args ...any)

func (*Logger) Error

func (logger *Logger) Error(args ...any)

func (*Logger) ErrorFn added in v1.7.0

func (logger *Logger) ErrorFn(fn LogFunction)

func (*Logger) Errorf

func (logger *Logger) Errorf(format string, args ...any)

func (*Logger) Errorln

func (logger *Logger) Errorln(args ...any)

func (*Logger) Exit added in v1.2.0

func (logger *Logger) Exit(code int)

func (*Logger) Fatal

func (logger *Logger) Fatal(args ...any)

func (*Logger) FatalFn added in v1.7.0

func (logger *Logger) FatalFn(fn LogFunction)

func (*Logger) Fatalf

func (logger *Logger) Fatalf(format string, args ...any)

func (*Logger) Fatalln

func (logger *Logger) Fatalln(args ...any)

func (*Logger) GetLevel added in v1.1.0

func (logger *Logger) GetLevel() Level

GetLevel returns the logger level.

func (*Logger) Info

func (logger *Logger) Info(args ...any)

func (*Logger) InfoFn added in v1.7.0

func (logger *Logger) InfoFn(fn LogFunction)

func (*Logger) Infof

func (logger *Logger) Infof(format string, args ...any)

func (*Logger) Infoln

func (logger *Logger) Infoln(args ...any)

func (*Logger) IsLevelEnabled added in v1.1.0

func (logger *Logger) IsLevelEnabled(level Level) bool

IsLevelEnabled checks if logging for the given level is enabled.

func (*Logger) Log added in v1.3.0

func (logger *Logger) Log(level Level, args ...any)

Log logs a message at the specified level.

Using Log with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. Log treats the level as logging severity only; use Logger.Panic or Logger.Fatal when those side effects are desired.

func (*Logger) LogFn added in v1.7.0

func (logger *Logger) LogFn(level Level, fn LogFunction)

LogFn logs a message returned by fn at the specified level.

Using LogFn with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. LogFn treats the level as logging severity only; use Logger.PanicFn or Logger.FatalFn when those side effects are desired.

func (*Logger) Logf added in v1.3.0

func (logger *Logger) Logf(level Level, format string, args ...any)

Logf logs a formatted message at the specified level.

Using Logf with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. Logf treats the level as logging severity only; use Logger.Panicf or Logger.Fatalf when those side effects are desired.

func (*Logger) Logln added in v1.3.0

func (logger *Logger) Logln(level Level, args ...any)

Logln logs a message at the specified level with Println-style spacing.

Using Logln with PanicLevel or FatalLevel intentionally does not trigger a panic or exit. Logln treats the level as logging severity only; use Logger.Panicln or Logger.Fatalln when those side effects are desired.

func (*Logger) Panic

func (logger *Logger) Panic(args ...any)

func (*Logger) PanicFn added in v1.7.0

func (logger *Logger) PanicFn(fn LogFunction)

func (*Logger) Panicf

func (logger *Logger) Panicf(format string, args ...any)

func (*Logger) Panicln

func (logger *Logger) Panicln(args ...any)

func (*Logger) Print

func (logger *Logger) Print(args ...any)

func (*Logger) PrintFn added in v1.7.0

func (logger *Logger) PrintFn(fn LogFunction)

func (*Logger) Printf

func (logger *Logger) Printf(format string, args ...any)

func (*Logger) Println

func (logger *Logger) Println(args ...any)

func (*Logger) ReplaceHooks added in v1.1.0

func (logger *Logger) ReplaceHooks(hooks LevelHooks) LevelHooks

ReplaceHooks replaces the logger hooks and returns the old ones

func (*Logger) SetBufferPool added in v1.8.2

func (logger *Logger) SetBufferPool(pool BufferPool)

SetBufferPool sets the logger buffer pool.

func (*Logger) SetFormatter added in v1.1.0

func (logger *Logger) SetFormatter(formatter Formatter)

SetFormatter sets the logger formatter.

func (*Logger) SetLevel added in v1.0.3

func (logger *Logger) SetLevel(level Level)

SetLevel sets the logger level.

func (*Logger) SetNoLock added in v0.11.0

func (logger *Logger) SetNoLock()

SetNoLock disables the lock for situations where a file is opened with appending mode, and safe for concurrent writes to the file (within 4k message on Linux). In these cases user can choose to disable the lock.

func (*Logger) SetOutput added in v1.0.6

func (logger *Logger) SetOutput(output io.Writer)

SetOutput sets the logger output.

func (*Logger) SetReportCaller added in v1.2.0

func (logger *Logger) SetReportCaller(reportCaller bool)

SetReportCaller sets whether the caller stack frame must be logged.

func (*Logger) Trace added in v1.2.0

func (logger *Logger) Trace(args ...any)

func (*Logger) TraceFn added in v1.7.0

func (logger *Logger) TraceFn(fn LogFunction)

func (*Logger) Tracef added in v1.2.0

func (logger *Logger) Tracef(format string, args ...any)

func (*Logger) Traceln added in v1.2.0

func (logger *Logger) Traceln(args ...any)

func (*Logger) Warn

func (logger *Logger) Warn(args ...any)

func (*Logger) WarnFn added in v1.7.0

func (logger *Logger) WarnFn(fn LogFunction)

func (*Logger) Warnf

func (logger *Logger) Warnf(format string, args ...any)

func (*Logger) Warning

func (logger *Logger) Warning(args ...any)

func (*Logger) WarningFn added in v1.7.0

func (logger *Logger) WarningFn(fn LogFunction)

func (*Logger) Warningf

func (logger *Logger) Warningf(format string, args ...any)

func (*Logger) Warningln

func (logger *Logger) Warningln(args ...any)

func (*Logger) Warnln

func (logger *Logger) Warnln(args ...any)

func (*Logger) WithContext added in v1.4.0

func (logger *Logger) WithContext(ctx context.Context) *Entry

WithContext add a context to the log entry.

func (*Logger) WithError added in v0.9.0

func (logger *Logger) WithError(err error) *Entry

WithError adds an error as single field to the log entry. It calls Entry.WithError for the given error.

func (*Logger) WithField

func (logger *Logger) WithField(key string, value any) *Entry

WithField allocates a new entry and adds a field to it. Debug, Print, Info, Warn, Error, Fatal or Panic must be then applied to this new returned entry. If you want multiple fields, use `WithFields`.

func (*Logger) WithFields

func (logger *Logger) WithFields(fields Fields) *Entry

WithFields adds a struct of fields to the log entry. It calls Entry.WithField for each Field.

func (*Logger) WithTime added in v1.0.6

func (logger *Logger) WithTime(t time.Time) *Entry

WithTime overrides the time of the log entry.

func (*Logger) Writer added in v0.6.5

func (logger *Logger) Writer() *io.PipeWriter

Writer at INFO level. See WriterLevel for details.

Example (HttpServer)
package main

import (
	"log"
	"net/http"

	"github.com/sirupsen/logrus"
)

func main() {
	logger := logrus.New()
	w := logger.Writer()
	defer w.Close()

	srv := http.Server{
		// create a stdlib log.Logger that writes to
		// logrus.Logger.
		ErrorLog: log.New(w, "", 0),
	}

	if err := srv.ListenAndServe(); err != nil {
		logger.Fatal(err)
	}
}
Example (Stdlib)
package main

import (
	"log"

	"github.com/sirupsen/logrus"
)

func main() {
	logger := logrus.New()
	logger.Formatter = &logrus.JSONFormatter{}

	// Use logrus for standard log output
	// Note that `log` here references stdlib's log
	// Not logrus imported under the name `log`.
	log.SetOutput(logger.Writer())
}

func (*Logger) WriterLevel added in v0.11.0

func (logger *Logger) WriterLevel(level Level) *io.PipeWriter

WriterLevel returns an io.Writer that can be used to write arbitrary text to the logger at the given log level. Each line written to the writer will be printed in the usual way using formatters and hooks. The writer is part of an io.Pipe and it is the callers responsibility to close the writer when done. This can be used to override the standard library logger easily.

type MutexWrap deprecated added in v0.11.0

type MutexWrap = mutexWrap

MutexWrap is the mutex implementation used by Logger.

Deprecated: MutexWrap is an implementation detail of Logger and should not be used directly.

type StdLogger

type StdLogger interface {
	Print(args ...any)
	Printf(format string, args ...any)
	Println(args ...any)

	Fatal(args ...any)
	Fatalf(format string, args ...any)
	Fatalln(args ...any)

	Panic(args ...any)
	Panicf(format string, args ...any)
	Panicln(args ...any)
}

StdLogger is what your logrus-enabled library should take, that way it'll accept a stdlib logger (log.Logger) and a logrus logger. There's no standard interface, so this is the closest we get, unfortunately.

type TextFormatter

type TextFormatter struct {
	// Set to true to bypass checking for a TTY before outputting colors.
	ForceColors bool

	// Force disabling colors.
	DisableColors bool

	// Force quoting of all values
	ForceQuote bool

	// DisableQuote disables quoting for all values.
	// DisableQuote will have a lower priority than ForceQuote.
	// If both of them are set to true, quote will be forced on all values.
	DisableQuote bool

	// Override coloring based on CLICOLOR and CLICOLOR_FORCE. - https://bixense.com/clicolors/
	EnvironmentOverrideColors bool

	// Disable timestamp logging. useful when output is redirected to logging
	// system that already adds timestamps.
	DisableTimestamp bool

	// Enable logging the full timestamp when a TTY is attached instead of just
	// the time passed since beginning of execution.
	FullTimestamp bool

	// TimestampFormat to use for display when a full timestamp is printed.
	// The format to use is the same than for time.Format or time.Parse from the standard
	// library.
	// The standard Library already provides a set of predefined format.
	TimestampFormat string

	// The fields are sorted by default for a consistent output. For applications
	// that log extremely frequently and don't use the JSON formatter this may not
	// be desired.
	DisableSorting bool

	// The keys sorting function, when uninitialized it uses slices.Sort.
	SortingFunc func([]string)

	// Disables the truncation of the level text to 4 characters.
	DisableLevelTruncation bool

	// PadLevelText Adds padding the level text so that all the levels output at the same length
	// PadLevelText is a superset of the DisableLevelTruncation option
	PadLevelText bool

	// QuoteEmptyFields will wrap empty fields in quotes if true
	QuoteEmptyFields bool

	// FieldMap allows users to customize the names of keys for default fields.
	// Mapped keys are written as-is, so they should be safe for plain-text output.
	//
	// As an example:
	//
	// formatter := &TextFormatter{
	// 	FieldMap: FieldMap{
	// 		FieldKeyTime:  "@timestamp",
	// 		FieldKeyLevel: "@level",
	// 		FieldKeyMsg:   "@message",
	// 	},
	// }
	FieldMap FieldMap

	// CallerPrettyfier can be set by the user to modify the content
	// of the function and file keys in the data when ReportCaller is
	// activated. If any of the returned value is the empty string the
	// corresponding key will be removed from fields.
	CallerPrettyfier func(*runtime.Frame) (function string, file string)
	// contains filtered or unexported fields
}

TextFormatter formats logs into text.

Output is logfmt-like: key=value pairs separated by spaces. Fields from Entry.Data are included together with the standard fields derived from the entry. If a field conflicts with a standard field, it is prefixed with "fields.". Standard field names can be customized through FieldMap.

Field keys are written as-is (unquoted and unescaped) in the plain (non-colored) format; only field values may be quoted depending on DisableQuote, ForceQuote, QuoteEmptyFields, and the value content.

When colors are enabled, ANSI escape sequences may be added for presentation. For fully escaped structured output (including safe keys), use JSONFormatter.

func (*TextFormatter) Format

func (f *TextFormatter) Format(entry *Entry) ([]byte, error)

Format renders a single log entry

type TraceLogger added in v1.10.0

type TraceLogger interface {
	Trace(args ...any)
	Tracef(format string, args ...any)
	Traceln(args ...any)
}

TraceLogger provides convenience functions to log messages at level TraceLevel.

type WarnLogger added in v1.10.0

type WarnLogger interface {
	Warn(args ...any)
	Warnf(format string, args ...any)
	Warnln(args ...any)
}

WarnLogger provides convenience functions to log messages at level WarnLevel.

Directories

Path Synopsis
hooks
slog
Package slog provides adapters between Logrus and log/slog.
Package slog provides adapters between Logrus and log/slog.
test
Package test is used for testing logrus.
Package test is used for testing logrus.
internal

Jump to